[SCM] WebKit Debian packaging branch, debian/experimental, updated. debian/1.3.8-1-1049-g2e11a8e

dbates at webkit.org dbates at webkit.org
Fri Jan 21 14:52:05 UTC 2011


The following commit has been merged in the debian/experimental branch:
commit 282eb96bc8029bde4db48fdc9768c68846d2390e
Author: dbates at webkit.org <dbates at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Mon Jan 3 17:59:48 2011 +0000

    2011-01-03  Daniel Bates  <dbates at rim.com>
    
            Attempt to fix the Chromium Linux Release build after changeset 74895 <http://trac.webkit.org/changeset/74895>.
    
            The portion of the patch in <https://bugs.webkit.org/show_bug.cgi?id=51791> that modified the
            file src/WebSearchableFormData.cpp was not landed (why?). Although the change log entry
            associated with this change was landed.
    
            * src/WebSearchableFormData.cpp:
            (HTMLNames::IsInDefaultState):
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@74899 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/chromium/ChangeLog b/WebKit/chromium/ChangeLog
index 26439d2..6ef058c 100644
--- a/WebKit/chromium/ChangeLog
+++ b/WebKit/chromium/ChangeLog
@@ -1,3 +1,14 @@
+2011-01-03  Daniel Bates  <dbates at rim.com>
+
+        Attempt to fix the Chromium Linux Release build after changeset 74895 <http://trac.webkit.org/changeset/74895>.
+
+        The portion of the patch in <https://bugs.webkit.org/show_bug.cgi?id=51791> that modified the
+        file src/WebSearchableFormData.cpp was not landed (why?). Although the change log entry
+        associated with this change was landed.
+
+        * src/WebSearchableFormData.cpp:
+        (HTMLNames::IsInDefaultState):
+
 2011-01-02  Dirk Schulze  <krit at webkit.org>
 
         Reviewed by Simon Fraser.
diff --git a/WebKit/chromium/src/WebSearchableFormData.cpp b/WebKit/chromium/src/WebSearchableFormData.cpp
index 178e4db..8e27a67 100644
--- a/WebKit/chromium/src/WebSearchableFormData.cpp
+++ b/WebKit/chromium/src/WebSearchableFormData.cpp
@@ -46,6 +46,7 @@
 #include "WebFormElement.h"
 
 using namespace WebCore;
+using namespace HTMLNames;
 
 namespace {
 
@@ -128,13 +129,13 @@ bool IsSelectInDefaultState(const HTMLSelectElement* select)
 // Returns true if the form element is in its default state, false otherwise.
 // The default state is the state of the form element on initial load of the
 // page, and varies depending upon the form element. For example, a checkbox is
 // in its default state if the checked state matches the defaultChecked state.
 bool IsInDefaultState(const HTMLFormControlElement* formElement)
 {
     if (formElement->hasTagName(HTMLNames::inputTag)) {
         const HTMLInputElement* inputElement = static_cast<const HTMLInputElement*>(formElement);
         if (inputElement->isCheckbox() || inputElement->isRadioButton())
-            return inputElement->checked() == inputElement->defaultChecked();
+            return inputElement->checked() == inputElement->hasAttribute(checkedAttr);
     } else if (formElement->hasTagName(HTMLNames::selectTag))
         return IsSelectInDefaultState(static_cast<const HTMLSelectElement*>(formElement));
     return true;
@@ -128,13 +129,13 @@ bool IsSelectInDefaultState(const HTMLSelectElement* select)
 // The default state is the state of the form element on initial load of the
 // page, and varies depending upon the form element. For example, a checkbox is
-// in its default state if the checked state matches the defaultChecked state.
+// in its default state if the checked state matches the state of the checked attribute.
 bool IsInDefaultState(const HTMLFormControlElement* formElement)
 {

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list